Module utils

Module utils 

Functions

array_to_binary_iter
Converts any array that can be cast to a binary array into an iterator of Option<Vec<u8>>
array_to_bool_iter
Converts any array that can be cast to a boolean array into an iterator of Option<bool>
array_to_f32_iter
Converts any array to an iterator of Option<f32>
array_to_f64_iter
Converts any array to an iterator of Option<f64>
array_to_i8_iter
Converts any array to an iterator of Option<i8>
array_to_i16_iter
Converts any array to an iterator of Option<i16>
array_to_i32_iter
Converts any array to an iterator of Option<i32>
array_to_i64_iter
Converts any array to an iterator of Option<i64>
array_to_list_vec
Modify the items for list-like arrays
array_to_native_iter
Directly converts an arrow PrimitiveArray to a rust primitive type
array_to_string_iter
Converts any array that can be cast to a string array into an iterator of Option<String>
array_to_u8_iter
Converts any array to an iterator of Option<u8>
array_to_u16_iter
Converts any array to an iterator of Option<u16>
array_to_u32_iter
Converts any array to an iterator of Option<u32>
array_to_u64_iter
Converts any array to an iterator of Option<u64>
array_to_values
Converts a ArrayRefs to clickhouse values
batch_to_rows
Converts a RecordBatch to an iterator of rows, where each row is a Vec of Values.
split_record_batch
Splits a RecordBatch into multiple RecordBatches, each containing at most max rows.