Function array_to_binary_iter

pub fn array_to_binary_iter(
    array: &dyn Array,
) -> Result<impl Iterator<Item = Option<Vec<u8>>>>
Converts any array that can be cast to a binary array into an iterator of Option<Vec<u8>>

Errors

Returns an error if the array cannot be cast to a binary array.