array_to_bool_iter

Function array_to_bool_iter 

pub fn array_to_bool_iter(
    array: &dyn Array,
) -> Result<impl Iterator<Item = Option<bool>>>
Converts any array that can be cast to a boolean array into an iterator of Option<bool>

Errors

Returns an error if the array cannot be cast to a bool array.