Function array_to_string_iter

pub fn array_to_string_iter(
    array: &dyn Array,
) -> Result<impl Iterator<Item = Option<String>>>
Converts any array that can be cast to a string array into an iterator of Option<String>

Errors

Returns an error if the array cannot be cast to a string array.