Struct Block

pub struct Block {
    pub info: BlockInfo,
    pub rows: u64,
    pub column_types: Vec<(String, Type)>,
    pub column_data: Vec<Value>,
}
A chunk of data in columnar form.

Fields

info: BlockInfo

Metadata about the block

rows: u64

The number of rows contained in the block

column_types: Vec<(String, Type)>

The type of each column by name, in order.

column_data: Vec<Value>

The data of each column by name, in order. All Value should correspond to the associated type in column_types.

Implementations

Source

impl Block

pub fn take_iter_rows( &mut self, ) -> BlockRowValueIter<'_, impl Iterator<Item = Value>>

Iterate over all rows with owned values.

pub fn estimate_size(&self) -> usize

Estimate the serialized size of this block for buffer allocation

pub fn from_rows<T: Row>( rows: Vec<T>, schema: Vec<(String, Type)>, ) -> Result<Self>

Create a block from a vector of rows and a schema.

Errors

Returns an error if the number of rows does not match the number of columns, serializing fails, or the field cannot be found in the schema.