RawRow

Struct RawRow 

pub struct RawRow(/* private fields */);
A row of raw data returned from the database by a query. Or an unstructured runtime-defined row to upload to the server.

Implementations

Source

impl RawRow

pub fn is_empty(&self) -> bool

Determines if the row contains no values.

pub fn len(&self) -> usize

Returns the number of values in the row.

pub fn into_values(self) -> Vec<(Type, Value)>

Panics

Panics if any of the values are None

pub fn try_get<I: RowIndex, T: FromSql>(&mut self, index: I) -> Result<T>

Like RawRow::get, but returns a Result rather than panicking.

Errors

Returns an error if the index is out of bounds or if the value cannot be converted to the specified

Panics

Shouldn’t panic, bounds checked

pub fn get<I: RowIndex, T: FromSql>(&mut self, index: I) -> T

Deserializes a value from the row. The value can be specified either by its numeric index in the row, or by its column name.

Panics

Panics if the index is out of bounds or if the value cannot be converted to the specified type.

pub fn try_set_typed( &mut self, name: &impl ToString, type_: Option<Type>, value: impl ToSql, ) -> Result<()>

Sets or inserts a column value with a given name. type_ is inferred if None. Index is defined on insertion order.

Errors

Returns an error if type conversion fails.

Panics

Shouldn’t panic as current_position checks for existence of element

pub fn try_set(&mut self, name: &impl ToString, value: impl ToSql) -> Result<()>

Same as try_set_typed, but always infers the type

Errors

Returns an error if type conversion fails.

pub fn set(&mut self, name: &impl ToString, value: impl ToSql)

Same as try_set, but panics on type conversion failure.

Panics

Panics on type conversion failure

pub fn set_typed( &mut self, name: &impl ToString, type_: Option<Type>, value: impl ToSql, )

Same as try_set_typed, but panics on type conversion failure.

Panics

Panics on type conversion failure