Module values

Module values 

Modules

json
vec_tuple

Structs

Bytes
Wrapper over Vec<u8> to allow more efficient serialization/deserialization of raw bytes The corresponding ClickHouse type here is Type::String or Type::FixedSizedString, not Type::Array. Conversion to Type::Array(UInt8) will happen, but it is not efficient.
Date
Wrapper type for ClickHouse Date type.
Date32
Wrapper type for ClickHouse Date32 type.
DateTime
Wrapper type for ClickHouse DateTime type.
DateTime64
Wrapper type for ClickHouse DateTime64 type.
DynDateTime64
Wrapper type for ClickHouse DateTime64 type with dynamic precision.
FixedPoint32
Wrapper type for ClickHouse FixedPoint32 type.
FixedPoint64
Wrapper type for ClickHouse FixedPoint64 type.
FixedPoint128
Wrapper type for ClickHouse FixedPoint128 type.
FixedPoint256
Wrapper type for ClickHouse FixedPoint256 type.
Ipv4
Wrapper type for ClickHouse IPv4 type.
Ipv6
Wrapper type for ClickHouse IPv6 type.
MultiPolygon
Union of polygons.
Point
Geo point, represented by its x and y coordinates.
Polygon
Polygon with holes. The first element is the outer polygon, and the following ones are the holes.
Ring
Polygon without holes.
i256
Wrapper type for ClickHouse Int256 type.
u256
Wrapper type for ClickHouse UInt256 type.

Enums

Value
A raw ClickHouse value. Types are not strictly/completely preserved (i.e. types Type::String and Type::FixedString both are value Type::String). Use this if you want dynamically typed queries.