pub struct DateTime(pub Tz, pub u32);Expand description
Wrapper type for ClickHouse DateTime type.
Tuple Fields
0: Tz1: u32Implementations
Sourceimpl DateTime
impl DateTime
Sourcepub fn from_chrono_infallible(other: DateTime<Tz>) -> Self
pub fn from_chrono_infallible(other: DateTime<Tz>) -> Self
Infallible from implemenation for chrono::DateTime<Tz>.
IMPORTANT: This will truncate a value that is too large for the target type.
Use TryFrom for the fallible version.
Sourcepub fn from_chrono_infallible_utc(other: DateTime<Utc>) -> Self
pub fn from_chrono_infallible_utc(other: DateTime<Utc>) -> Self
Infallible from implemenation for chrono::DateTime<Utc>.
IMPORTANT: This will truncate a value that is too large for the target type.
Use TryFrom for the fallible version.
Sourcepub fn from_seconds(seconds: i64, tz: Option<Arc<str>>) -> Self
pub fn from_seconds(seconds: i64, tz: Option<Arc<str>>) -> Self
Panics
Panics if the number of seconds is out of range for a u32.
Sourcepub fn from_millis(ms: i64, tz: Option<Arc<str>>) -> Self
pub fn from_millis(ms: i64, tz: Option<Arc<str>>) -> Self
Panics
Panics if the number of milliseconds is out of range for a u32.