pub struct DynDateTime64(pub Tz, pub u64, pub usize);Expand description
Wrapper type for ClickHouse DateTime64 type with dynamic precision.
Tuple Fields
0: Tz1: u642: usizeImplementations
Sourceimpl DynDateTime64
impl DynDateTime64
Sourcepub fn from_seconds(seconds: i64, tz: Option<Arc<str>>) -> Self
pub fn from_seconds(seconds: i64, tz: Option<Arc<str>>) -> Self
Panics
Panics if seconds is negative.
Sourcepub fn from_millis(ms: i64, tz: Option<Arc<str>>) -> Self
pub fn from_millis(ms: i64, tz: Option<Arc<str>>) -> Self
Panics
Panics if milliseconds is negative.
Sourceimpl DynDateTime64
impl DynDateTime64
Sourcepub fn try_from_utc(
other: DateTime<Utc>,
precision: usize,
) -> Result<Self, TryFromIntError>
pub fn try_from_utc( other: DateTime<Utc>, precision: usize, ) -> Result<Self, TryFromIntError>
Errors
Returns an error if the timestamp cannot be converted to a u64.
Sourceimpl DynDateTime64
impl DynDateTime64
Sourcepub fn try_from_tz(
other: DateTime<Tz>,
precision: usize,
) -> Result<Self, TryFromIntError>
pub fn try_from_tz( other: DateTime<Tz>, precision: usize, ) -> Result<Self, TryFromIntError>
Errors
Returns an error if the timestamp cannot be converted to a u64.