pub struct FixedPoint256<const SCALE: u64>(pub i256);Expand description
Wrapper type for ClickHouse FixedPoint256 type.
Tuple Fields
0: i256Implementations
Sourceimpl<const SCALE: u64> FixedPoint256<SCALE>
impl<const SCALE: u64> FixedPoint256<SCALE>
Sourcepub const MAX: Self
pub const MAX: Self
The maximum value for FixedPoint256
Sourcepub const MIN: Self
pub const MIN: Self
The minimum value for FixedPoint256
Sourcepub fn from_raw(value: i128) -> Self
pub fn from_raw(value: i128) -> Self
Create a fixed-point number from a raw scaled integer value The value is assumed to already have the correct scaling applied
Sourcepub fn from_parts(value: i128, exponent: i32) -> Self
pub fn from_parts(value: i128, exponent: i32) -> Self
Create a fixed-point number from a value and decimal exponent e.g., (123, -2) represents 123 × 10^-2 = 1.23
Sourcepub fn is_negative(&self) -> bool
pub fn is_negative(&self) -> bool
Check if the value is negative