pub struct Block {
pub info: BlockInfo,
pub rows: u64,
pub column_types: Vec<(String, Type)>,
pub column_data: Vec<Value>,
}Expand description
A chunk of data in columnar form.
Fields
info: BlockInfoMetadata about the block
rows: u64The number of rows contained in the block
column_types: Vec<(String, Type)>The type of each column by name, in order.
column_data: Vec<Value>The data of each column by name, in order. All Value should correspond to the associated
type in column_types.
Implementations
Sourceimpl Block
impl Block
Sourcepub fn take_iter_rows(
&mut self,
) -> BlockRowValueIter<'_, impl Iterator<Item = Value>> ⓘ
pub fn take_iter_rows( &mut self, ) -> BlockRowValueIter<'_, impl Iterator<Item = Value>> ⓘ
Iterate over all rows with owned values.
Sourcepub fn estimate_size(&self) -> usize
pub fn estimate_size(&self) -> usize
Estimate the serialized size of this block for buffer allocation